@@ -3,12 +3,12 @@ from jwt.exceptions import ExpiredSignatureError
     
 my_secret = 't0k#N$#CR#T'
 
-def generateJWTToken(username):
+def generateJWTToken(name):
     
     payload_data = {
         "sub": "1313",
-        "name": username,
-        "nickname": username[0:2]
+        "name": name,
+        "nickname": name[0:2]
     }
     
     try:
@@ -24,12 +24,11 @@ def generateJWTToken(username):
         print(f'Unable to encode the token, error: {error}')
 
 
-def verifyJWTToken(token):
+def verifyJWTToken(name, token):
     
     try:
     
         header_data = jwt.get_unverified_header(token)
-        #print("header: ", header_data)
         
         decoded_payload = jwt.decode(
             token,
@@ -37,7 +36,10 @@ def verifyJWTToken(token):
             algorithms=[header_data['alg'], ]
         )
     
-        return decoded_payload
+        if name == decoded_payload['name']:
+            return True
+        
+        return False
 
     except ExpiredSignatureError as error:
         print(f'Unable to decode the token, error: {error}')
@@ -45,11 +47,11 @@ def verifyJWTToken(token):
 #Testing code here    
 if __name__ == '__main__':
     
-    username = "Raj"
+    name = "Raj"
     
     #Success Scenario
-    token = generateJWTToken(username)
+    token = generateJWTToken(name)
     print("\n Generated Token: {}".format(token))
 
-    decodedValue = verifyJWTToken(token)
-    print("\n Decoded Payload: {}".format(decodedValue))
\ No newline at end of file
+    is_token_valid = verifyJWTToken(name, token)
+    print("\n Token valid: {}".format(is_token_valid))
\ No newline at end of file
